@@ -14,13 +14,13 @@ The radial controller report descriptor used is described by Microsoft
 """
 # pylint: enable=line-too-long
 
-__version__ = "1.0.1"
+__version__ = "1.0.2"
 __repo__ = "https://github.com/adafruit/Adafruit_CircuitPython_Radial_Controller.git"
 
 import usb_hid
 
 
-def device(report_id):
+def device(report_id: int) -> usb_hid.Device:
     """Create a `usb_hid.Device` for a radial controller.
 
     :param int report_id: The report ID to use for the device.
